Write counts, metadata, taxonomy, and phylogeny to a biom file.
write.biom(biom, file, format = "json")The BIOM object to save to the file.
Path to the output file.
Options are “tab”, “json”, and “hdf5”, corresponding to classic tabular format, biom format version 1.0 and biom version 2.1, respectively. Abbreviations are also accepted. See http://biom-format.org/documentation/ for details.
On success, returns NULL invisibly.