Converts your rbiom object into other common Bioconductor data structures.
Each function requires the corresponding target package to be installed.
Usage
convert_to_animalcules(biom, ...)
convert_to_biomformat(biom, ...)
convert_to_phyloseq(biom, ...)
convert_to_SE(biom, ...)
convert_to_TSE(biom, ...)Arguments
- biom
An rbiom object, or any value accepted by
as_rbiom().- ...
Not Used.
Value
An animalcules (MultiAssayExperiment class), biomformat (biom class), phyloseq,
SummarizedExperiment, or TreeSummarizedExperiment object.
Details
convert_to_animalcules(): Converts to aMultiAssayExperimentobject tailored for the animalcules interactive microbiome analysis toolkit. Includes: counts, metadata, and taxonomy.convert_to_biomformat(): Converts to abiomobject used by the biomformat package, the standard Bioconductor class for reading and writing BIOM data. Includes: counts, metadata, and taxonomy.convert_to_phyloseq(): Converts to aphyloseqobject for use with the comprehensive phyloseq ecosystem. Includes: counts, metadata, taxonomy, phylogenetic tree, and sequences.convert_to_SE(): Converts to aSummarizedExperimentobject, a core SummarizedExperiment Bioconductor container for matrix-like data and annotations. Includes: counts, metadata, and taxonomy.convert_to_TSE(): Converts to aTreeSummarizedExperimentobject. This extends the SE class to natively support hierarchical TreeSummarizedExperiment relationships. Includes: counts, metadata, taxonomy, phylogenetic tree, and sequences.
Examples
if (FALSE) { # \dontrun{
library(rbiom)
print(hmp50)
# Requires 'animalcules', a Bioconductor R package
if (nzchar(system.file(package = "animalcules"))) {
ani <- convert_to_animalcules(hmp50)
print(ani)
}
# Requires 'biomformat', a Bioconductor R package
if (nzchar(system.file(package = "biomformat"))) {
bio <- convert_to_biomformat(hmp50)
print(bio)
}
# Requires 'phyloseq', a Bioconductor R package
if (nzchar(system.file(package = "phyloseq"))) {
phy <- convert_to_phyloseq(hmp50)
print(phy)
}
# Requires 'SummarizedExperiment', a Bioconductor R package
if (nzchar(system.file(package = "SummarizedExperiment"))) {
se <- convert_to_SE(hmp50)
print(se)
}
# Requires 'TreeSummarizedExperiment', a Bioconductor R package
if (nzchar(system.file(package = "TreeSummarizedExperiment"))) {
tse <- convert_to_TSE(hmp50)
print(tse)
}
} # }